@@ -8,9 +8,9 @@ from __future__ import annotations
 import asyncio
 import json
 import logging
-from typing import TYPE_CHECKING, Literal
+from typing import TYPE_CHECKING, Any, Literal
 
-import rich
+from rich._spinners import SPINNERS
 from rich.panel import Panel
 from rich.progress import BarColumn, MofNCompleteColumn, Progress, SpinnerColumn, TextColumn, TimeElapsedColumn, TimeRemainingColumn
 
@@ -46,8 +46,8 @@ def run_tests(ctx: click.Context) -> AntaRunContext:
     test = nrfu_ctx_params["test"] or None
     dry_run = nrfu_ctx_params["dry_run"]
 
-    catalog = ctx.obj["catalog"]
-    inventory = ctx.obj["inventory"]
+    catalog: AntaCatalog = ctx.obj["catalog"]
+    inventory: AntaInventory = ctx.obj["inventory"]
 
     print_settings(inventory, catalog)
     with anta_progress_bar() as AntaTest.progress:
@@ -82,18 +82,20 @@ def print_settings(
     console.print()
 
 
-def print_table(ctx: click.Context, group_by: Literal["device", "test"] | None = None) -> None:
+def print_table(ctx: click.Context, group_by: Literal["device", "test"] | None = None, sort_by: tuple[str] | None = None) -> None:
     """Print result in a table."""
     reporter = ReportTable()
     console.print()
     results = _get_result_manager(ctx)
+    if sort_by:
+        results = _get_result_manager(ctx).sort(list(sort_by))
 
     if group_by == "device":
-        console.print(reporter.report_summary_devices(results))
+        console.print(reporter.generate_summary_by_device(results))
     elif group_by == "test":
-        console.print(reporter.report_summary_tests(results))
+        console.print(reporter.generate_summary_by_test(results))
     else:
-        console.print(reporter.report_all(results))
+        console.print(reporter.generate(results))
 
 
 def print_json(ctx: click.Context, output: pathlib.Path | None = None) -> None:
@@ -103,7 +105,7 @@ def print_json(ctx: click.Context, output: pathlib.Path | None = None) -> None:
     if output is None:
         console.print()
         console.print(Panel("JSON results", style="cyan"))
-        rich.print_json(results.json)
+        console.print_json(results.json)
     else:
         try:
             with output.open(mode="w", encoding="utf-8") as file:
@@ -161,7 +163,7 @@ def save_markdown_report(ctx: click.Context, md_output: pathlib.Path, run_contex
         Optional `AntaRunContext` instance returned from `AntaRunner.run()`.
         If provided, a `Run Overview` section will be generated in the report including the run context information.
     """
-    extra_data = None
+    extra_data: dict[str, Any] | None = None
     if run_context is not None:
         active_filters_dict = {}
         if run_context.filters.tags:
@@ -196,26 +198,23 @@ def save_markdown_report(ctx: click.Context, md_output: pathlib.Path, run_contex
         ctx.exit(ExitCode.USAGE_ERROR)
 
 
-# Adding our own ANTA spinner - overriding rich SPINNERS for our own
-# so ignore warning for redefinition
-rich.spinner.SPINNERS = {  # type: ignore[attr-defined]
-    "anta": {
-        "interval": 150,
-        "frames": [
-            "(     🐜)",
-            "(    🐜 )",
-            "(   🐜  )",
-            "(  🐜   )",
-            "( 🐜    )",
-            "(🐜     )",
-            "(🐌     )",
-            "( 🐌    )",
-            "(  🐌   )",
-            "(   🐌  )",
-            "(    🐌 )",
-            "(     🐌)",
-        ],
-    },
+# Adding our own ANTA spinner
+SPINNERS["anta"] = {
+    "interval": 150,
+    "frames": [
+        "(     🐜)",
+        "(    🐜 )",
+        "(   🐜  )",
+        "(  🐜   )",
+        "( 🐜    )",
+        "(🐜     )",
+        "(🐌     )",
+        "( 🐌    )",
+        "(  🐌   )",
+        "(   🐌  )",
+        "(    🐌 )",
+        "(     🐌)",
+    ],
 }
 
 
