@@ -8,8 +8,9 @@ from __future__ import annotations
 import enum
 import functools
 import logging
+import sys
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Literal
+from typing import TYPE_CHECKING, Any, Literal, TypeVar, cast
 
 import click
 from yaml import YAMLError
@@ -20,10 +21,19 @@ from anta.inventory.exceptions import InventoryIncorrectSchemaError, InventoryRo
 from anta.logger import anta_log_exception
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from click import Option
 
+if sys.version_info >= (3, 12):
+    from typing import override
+else:
+    from typing_extensions import override
+
 logger = logging.getLogger(__name__)
 
+R = TypeVar("R")
+
 
 class ExitCode(enum.IntEnum):
     """Encodes the valid exit codes by anta inspired from pytest."""
@@ -40,8 +50,7 @@ class ExitCode(enum.IntEnum):
     TESTS_FAILED = 4
 
 
-def parse_tags(ctx: click.Context, param: Option, value: str | None) -> set[str] | None:
-    # ruff: noqa: ARG001
+def parse_tags(_ctx: click.Context, _param: Option, value: str | None) -> set[str] | None:
     """Click option callback to parse an ANTA inventory tags."""
     if value is not None:
         return set(value.split(",")) if "," in value else {value}
@@ -91,8 +100,10 @@ class AliasedGroup(click.Group):
     From Click documentation.
     """
 
-    def get_command(self, ctx: click.Context, cmd_name: str) -> Any:
-        """Todo: document code."""
+    # Adding noqa because https://github.com/astral-sh/ruff/issues/5474, same for pylint
+    @override  # noqa: RET503
+    def get_command(self, ctx: click.Context, cmd_name: str) -> click.Command | click.Group | None:  # pylint: disable=R1710
+        """Try to find a command name based on a prefix."""
         rv = click.Group.get_command(self, ctx, cmd_name)
         if rv is not None:
             return rv
@@ -102,18 +113,17 @@ class AliasedGroup(click.Group):
         if len(matches) == 1:
             return click.Group.get_command(self, ctx, matches[0])
         ctx.fail(f"Too many matches: {', '.join(sorted(matches))}")
-        return None
 
-    def resolve_command(self, ctx: click.Context, args: Any) -> Any:
-        """Todo: document code."""
-        # always return the full command name
+    @override
+    def resolve_command(self, ctx: click.Context, args: list[str]) -> tuple[str | None, click.Command | None, list[str]]:
+        """Return the full command name as first tuple element."""
         _, cmd, args = super().resolve_command(ctx, args)
-        if not cmd:
-            return None, None, None
+        if not cmd or cmd.name is None:
+            return None, None, []
         return cmd.name, cmd, args
 
 
-def core_options(f: Callable[..., Any]) -> Callable[..., Any]:
+def core_options(f: Callable[..., R]) -> Callable[..., R]:
     """Click common options when requiring an inventory to interact with devices."""
 
     @click.option(
@@ -204,7 +214,7 @@ def core_options(f: Callable[..., Any]) -> Callable[..., Any]:
     @functools.wraps(f)
     def wrapper(
         ctx: click.Context,
-        *args: tuple[Any],
+        *,
         inventory: Path,
         username: str,
         password: str | None,
@@ -215,11 +225,11 @@ def core_options(f: Callable[..., Any]) -> Callable[..., Any]:
         insecure: bool,
         disable_cache: bool,
         inventory_format: Literal["json", "yaml"],
-        **kwargs: dict[str, Any],
-    ) -> Any:
+        **kwargs: Any,  # noqa: ANN401
+    ) -> R:
         # If help is invoke somewhere, do not parse inventory
         if ctx.obj.get("_anta_help"):
-            return f(*args, inventory=None, **kwargs)
+            return f(inventory=None, **kwargs)
         if prompt:
             # User asked for a password prompt
             if password is None:
@@ -255,12 +265,12 @@ def core_options(f: Callable[..., Any]) -> Callable[..., Any]:
         except (TypeError, ValueError, YAMLError, OSError, InventoryIncorrectSchemaError, InventoryRootKeyError) as e:
             anta_log_exception(e, f"Failed to parse the inventory: {inventory}", logger)
             ctx.exit(ExitCode.USAGE_ERROR)
-        return f(*args, inventory=i, **kwargs)
+        return f(inventory=i, **kwargs)
 
     return wrapper
 
 
-def inventory_options(f: Callable[..., Any]) -> Callable[..., Any]:
+def inventory_options(f: Callable[..., R]) -> Callable[..., R]:
     """Click common options when requiring an inventory to interact with devices."""
 
     @core_options
@@ -277,22 +287,21 @@ def inventory_options(f: Callable[..., Any]) -> Callable[..., Any]:
     @functools.wraps(f)
     def wrapper(
         ctx: click.Context,
-        *args: tuple[Any],
         tags: set[str] | None,
-        **kwargs: dict[str, Any],
-    ) -> Any:
+        **kwargs: Any,  # noqa: ANN401
+    ) -> R:
         # If help is invoke somewhere, do not parse inventory
         if ctx.obj.get("_anta_help"):
-            return f(*args, tags=tags, **kwargs)
-        return f(*args, tags=tags, **kwargs)
+            return f(tags=tags, **kwargs)
+        return f(tags=tags, **kwargs)
 
     return wrapper
 
 
-def catalog_options(*, required: bool = True) -> Callable[..., Callable[..., Any]]:
+def catalog_options(*, required: bool = True) -> Callable[..., Callable[..., R]]:
     """Click common options when requiring a test catalog to execute ANTA tests."""
 
-    def wrapper(f: Callable[..., Any]) -> Callable[..., Any]:
+    def wrapper(f: Callable[..., R]) -> Callable[..., R]:
         """Click common options when requiring a test catalog to execute ANTA tests."""
 
         @click.option(
@@ -322,23 +331,27 @@ def catalog_options(*, required: bool = True) -> Callable[..., Callable[..., Any
         @functools.wraps(f)
         def wrapper(
             ctx: click.Context,
-            *args: tuple[Any],
             catalog: Path | None,
             catalog_format: Literal["yaml", "json"],
-            **kwargs: dict[str, Any],
-        ) -> Any:
+            **kwargs: Any,  # noqa: ANN401
+        ) -> R:
             # If help is invoke somewhere, do not parse catalog
             if ctx.obj.get("_anta_help"):
-                return f(*args, catalog=None, **kwargs)
+                return f(catalog=None, **kwargs)
             if not catalog and not required:
-                return f(*args, catalog=None, **kwargs)
+                return f(catalog=None, **kwargs)
+            if not catalog:
+                # This should never happen
+                msg = "Missing catalog in inputs"
+                raise RuntimeError(msg)
             try:
-                file_format = catalog_format.lower()
-                c = AntaCatalog.parse(catalog, file_format=file_format)  # type: ignore[arg-type]
+                # the type checker needs help
+                file_format = cast('Literal["json", "yaml"]', catalog_format.lower())
+                c = AntaCatalog.parse(catalog, file_format=file_format)
             except (TypeError, ValueError, YAMLError, OSError) as e:
                 anta_log_exception(e, f"Failed to parse the catalog: {catalog}", logger)
                 ctx.exit(ExitCode.USAGE_ERROR)
-            return f(*args, catalog=c, **kwargs)
+            return f(catalog=c, **kwargs)
 
         return wrapper
 
