@@ -199,7 +199,14 @@ def convert_reload_cause(value: str) -> str:
     'System reloaded due to Zero Touch Provisioning'
     ```
     """
-    reload_causes = {"ZTP": "System reloaded due to Zero Touch Provisioning", "USER": "Reload requested by the user.", "FPGA": "Reload requested after FPGA upgrade"}
+    reload_causes = {
+        "ZTP": "System reloaded due to Zero Touch Provisioning",
+        "USER": "Reload requested by the user.",
+        "FPGA": "Reload requested after FPGA upgrade",
+        "USER_HITLESS": "Hitless reload requested by the user.",
+    }
+    if value in reload_causes.values():
+        return value
     if not reload_causes.get(value.upper()):
         msg = f"Invalid reload cause: '{value}' - expected causes are {list(reload_causes)}"
         raise ValueError(msg)
@@ -428,7 +435,16 @@ NTPStratumLevel = Annotated[int, Field(ge=0, le=16)]
 PowerSupplyFanStatus = Literal["failed", "ok", "unknownHwStatus", "powerLoss", "unsupported"]
 PowerSupplyStatus = Literal["ok", "unknown", "powerLoss", "failed"]
 ReloadCause = Annotated[
-    Literal["System reloaded due to Zero Touch Provisioning", "Reload requested by the user.", "Reload requested after FPGA upgrade", "USER", "FPGA", "ZTP"],
+    Literal[
+        "System reloaded due to Zero Touch Provisioning",
+        "Reload requested by the user.",
+        "Reload requested after FPGA upgrade",
+        "Hitless reload requested by the user.",
+        "USER",
+        "FPGA",
+        "ZTP",
+        "USER_HITLESS",
+    ],
     BeforeValidator(convert_reload_cause),
 ]
 BgpCommunity = Literal["standard", "extended", "large"]
