@@ -8,9 +8,10 @@ from __future__ import annotations
 import logging
 import re
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, ClassVar, TextIO
+from datetime import datetime, timedelta
+from typing import TYPE_CHECKING, Any, ClassVar, TextIO
 
-from anta.constants import MD_REPORT_TOC
+from anta.constants import ACRONYM_CATEGORIES, MD_REPORT_TOC, MD_REPORT_TOC_WITH_RUN_OVERVIEW
 from anta.logger import anta_log_exception
 from anta.result_manager.models import AntaTestStatus
 from anta.tools import convert_categories
@@ -32,7 +33,7 @@ class MDReportBase(ABC):
     to generate and write content to the provided markdown file.
     """
 
-    def __init__(self, mdfile: TextIO, results: ResultManager) -> None:
+    def __init__(self, mdfile: TextIO, results: ResultManager, extra_data: dict[str, Any] | None = None) -> None:
         """Initialize the MDReportBase with an open markdown file object to write to and a ResultManager instance.
 
         Parameters
@@ -41,9 +42,12 @@ class MDReportBase(ABC):
             An open file object to write the markdown data into.
         results
             The ResultsManager instance containing all test results.
+        extra_data
+            Optional extra data dictionary. Can be used by subclasses to render additional data.
         """
         self.mdfile = mdfile
         self.results = results
+        self.extra_data = extra_data
 
     @abstractmethod
     def generate_section(self) -> None:
@@ -141,6 +145,116 @@ class MDReportBase(ABC):
         # Replace newlines with <br> to preserve line breaks in HTML
         return text.replace("\n", "<br>")
 
+    def format_snake_case_to_title_case(self, value: str) -> str:
+        """Format a snake_case string to a Title Cased string with spaces, handling known network protocol or feature acronyms.
+
+        Parameters
+        ----------
+        value
+            A string value to be formatted.
+
+        Returns
+        -------
+        str
+            The value formatted in Title Cased.
+
+        Example
+        -------
+        - "hello_world" becomes "Hello World"
+        - "anta_version" becomes "ANTA Version"
+        """
+        if not value:
+            return ""
+
+        parts = value.split("_")
+        processed_parts = []
+        for part in parts:
+            if part.lower() in ACRONYM_CATEGORIES:
+                processed_parts.append(part.upper())
+            else:
+                processed_parts.append(part.capitalize())
+
+        return " ".join(processed_parts)
+
+    # Value could be anything
+    def format_value(self, value: Any) -> str:  # noqa: ANN401
+        """Format different types of values for display in the report.
+
+        Handles datetime, timedelta, lists, and other types by converting them to
+        human-readable string representations.
+
+        Handles only positive timedelta values.
+
+        Parameters
+        ----------
+        value
+            A value of any type to be formatted.
+
+        Returns
+        -------
+        str
+            The value formatted to a human-readable string.
+
+        Example
+        -------
+        - datetime.now() becomes "YYYY-MM-DD HH:MM:SS.milliseconds"
+        - timedelta(hours=1, minutes=5, seconds=30) becomes "1 hour, 5 minutes, 30 seconds"
+        - ["item1", "item2"] becomes "item1, item2"
+        - 123 becomes "123"
+        """
+        if isinstance(value, datetime):
+            return value.isoformat(sep=" ", timespec="milliseconds")
+
+        if isinstance(value, timedelta):
+            return self.format_timedelta(value)
+
+        if isinstance(value, list):
+            return ", ".join(str(v_item) for v_item in value)
+
+        return str(value)
+
+    def format_timedelta(self, value: timedelta) -> str:
+        """Format a timedelta object into a human-readable string.
+
+        Handles positive timedelta values. Milliseconds are shown only
+        if they are the sole component of a duration less than 1 second.
+        Does not format "days"; 2 days will return 48 hours.
+
+        Parameters
+        ----------
+        value
+            The timedelta object to be formatted.
+
+        Returns
+        -------
+        str
+            The timedelta object formatted to a human-readable string.
+        """
+        total_seconds = int(value.total_seconds())
+
+        if total_seconds < 0:
+            return "Invalid duration"
+
+        if total_seconds == 0 and value.microseconds == 0:
+            return "0 seconds"
+
+        parts = []
+
+        hours = total_seconds // 3600
+        if hours > 0:
+            parts.append(f"{hours} hour{'s' if hours != 1 else ''}")
+        minutes = (total_seconds % 3600) // 60
+        if minutes > 0:
+            parts.append(f"{minutes} minute{'s' if minutes != 1 else ''}")
+        seconds = total_seconds % 60
+        if seconds > 0:
+            parts.append(f"{seconds} second{'s' if seconds != 1 else ''}")
+        milliseconds = value.microseconds // 1000
+        if milliseconds > 0 and not parts and total_seconds == 0:
+            parts.append(f"{milliseconds} millisecond{'s' if milliseconds != 1 else ''}")
+
+        return ", ".join(parts) if parts else "0 seconds"
+
 
 class ANTAReport(MDReportBase):
     """Generate the `# ANTA Report` section of the markdown report."""
@@ -148,10 +262,53 @@ class ANTAReport(MDReportBase):
     def generate_section(self) -> None:
         """Generate the `# ANTA Report` section of the markdown report."""
         self.write_heading(heading_level=1)
-        toc = MD_REPORT_TOC
+        toc = MD_REPORT_TOC_WITH_RUN_OVERVIEW if self.extra_data else MD_REPORT_TOC
         self.mdfile.write(toc + "\n\n")
 
 
+class RunOverview(MDReportBase):
+    """Generate the `## Run Overview` section of the markdown report.
+
+    The `extra_data` dictionary containing the desired run information
+    must be provided to the initializer to generate this section.
+    """
+
+    def generate_section(self) -> None:
+        """Generate the `## Run Overview` section of the markdown report."""
+        if not self.extra_data:
+            return
+
+        md_lines = []
+        for key, value in self.extra_data.items():
+            label = self.format_snake_case_to_title_case(key)
+            item_prefix = f"- **{label}:**"
+            placeholder_for_none = "None"
+
+            if isinstance(value, list):
+                if not value:
+                    md_lines.append(f"{item_prefix} {placeholder_for_none}")
+                else:
+                    md_lines.append(item_prefix)
+                    md_lines.extend([f"  - {item!s}" for item in value])
+            elif isinstance(value, dict):
+                if not value:
+                    md_lines.append(f"{item_prefix} {placeholder_for_none}")
+                else:
+                    md_lines.append(item_prefix)
+                    for k, v_list_or_scalar in value.items():
+                        sub_label = self.format_snake_case_to_title_case(k)
+                        sub_value_str = self.format_value(v_list_or_scalar)
+                        md_lines.append(f"  - {sub_label}: {sub_value_str}")
+            # Scalar values
+            else:
+                formatted_value = self.format_value(value)
+                md_lines.append(f"{item_prefix} {formatted_value}")
+
+        self.write_heading(heading_level=2)
+        self.mdfile.write("\n".join(md_lines))
+        self.mdfile.write("\n\n")
+
+
 class TestResultsSummary(MDReportBase):
     """Generate the `## Test Results Summary` section of the markdown report."""
 
@@ -274,6 +431,7 @@ class MDReportGenerator:
 
     DEFAULT_SECTIONS: ClassVar[list[type[MDReportBase]]] = [
         ANTAReport,
+        RunOverview,
         TestResultsSummary,
         SummaryTotals,
         SummaryTotalsDeviceUnderTest,
@@ -282,7 +440,7 @@ class MDReportGenerator:
     ]
 
     @classmethod
-    def generate(cls, results: ResultManager, md_filename: Path) -> None:
+    def generate(cls, results: ResultManager, md_filename: Path, extra_data: dict[str, Any] | None = None) -> None:
         """Generate the sections of the markdown report defined in DEFAULT_SECTIONS using a single result manager instance for all sections.
 
         Parameters
@@ -291,18 +449,20 @@ class MDReportGenerator:
             The ResultsManager instance containing all test results.
         md_filename
             The path to the markdown file to write the report into.
+        extra_data
+            Optional extra data dictionary that can be used by the section generators to render additional data.
         """
         try:
             with md_filename.open("w", encoding="utf-8") as mdfile:
                 for section in cls.DEFAULT_SECTIONS:
-                    section(mdfile, results).generate_section()
+                    section(mdfile, results, extra_data).generate_section()
         except OSError as exc:
             message = f"OSError caught while writing the Markdown file '{md_filename.resolve()}'."
             anta_log_exception(exc, message, logger)
             raise
 
     @classmethod
-    def generate_sections(cls, sections: list[tuple[type[MDReportBase], ResultManager]], md_filename: Path) -> None:
+    def generate_sections(cls, sections: list[tuple[type[MDReportBase], ResultManager]], md_filename: Path, extra_data: dict[str, Any] | None = None) -> None:
         """Generate the different sections of the markdown report provided in the sections argument with each section using its own result manager instance.
 
         Parameters
@@ -311,11 +471,13 @@ class MDReportGenerator:
             A list of tuples, where each tuple contains a subclass of `MDReportBase` and an instance of `ResultManager`.
         md_filename
             The path to the markdown file to write the report into.
+        extra_data
+            Optional extra data dictionary that can be used by the section generators to render additional data.
         """
         try:
             with md_filename.open("w", encoding="utf-8") as md_file:
                 for section, rm in sections:
-                    section(md_file, rm).generate_section()
+                    section(md_file, rm, extra_data).generate_section()
         except OSError as exc:
             message = f"OSError caught while writing the Markdown file '{md_filename.resolve()}'."
             anta_log_exception(exc, message, logger)
