@@ -109,7 +109,7 @@ class VerifyReachability(AntaTest):
         """Main test function for VerifyReachability."""
         self.result.is_success()
 
-        for command, host in zip(self.instance_commands, self.inputs.hosts):
+        for command, host in zip(self.instance_commands, self.inputs.hosts, strict=False):
             message = command.json_output["messages"][0]
 
             # Extract the command failure details
@@ -153,6 +153,7 @@ class VerifyLLDPNeighbors(AntaTest):
     ```yaml
     anta.tests.connectivity:
       - VerifyLLDPNeighbors:
+          require_fqdn: False
           neighbors:
             - port: Ethernet1
               neighbor_device: DC1-SPINE1
@@ -160,6 +161,12 @@ class VerifyLLDPNeighbors(AntaTest):
             - port: Ethernet2
               neighbor_device: DC1-SPINE2
               neighbor_port: Ethernet1
+      - VerifyLLDPNeighbors:
+          require_fqdn: True
+          neighbors:
+            - port: Ethernet1
+              neighbor_device: DC1-SPINE1.local.com
+              neighbor_port: Ethernet1
     ```
     """
 
@@ -171,6 +178,8 @@ class VerifyLLDPNeighbors(AntaTest):
 
         neighbors: list[LLDPNeighbor]
         """List of LLDP neighbors."""
+        require_fqdn: bool = True
+        """If True (default), neighbor_device must exactly match the neighbor FQDN system name. If False, only the hostname portion is used for matching."""
         Neighbor: ClassVar[type[Neighbor]] = Neighbor
         """To maintain backward compatibility."""
 
@@ -191,9 +200,13 @@ class VerifyLLDPNeighbors(AntaTest):
 
             # Check if the system name and neighbor port matches
             match_found = any(
-                info["systemName"] == neighbor.neighbor_device and info["neighborInterfaceInfo"]["interfaceId_v2"] == neighbor.neighbor_port
+                (info["systemName"] if self.inputs.require_fqdn else info["systemName"].split(".")[0]) == neighbor.neighbor_device
+                and info["neighborInterfaceInfo"]["interfaceId_v2"] == neighbor.neighbor_port
                 for info in lldp_neighbor_info
             )
             if not match_found:
-                failure_msg = [f"{info['systemName']}/{info['neighborInterfaceInfo']['interfaceId_v2']}" for info in lldp_neighbor_info]
+                failure_msg = [
+                    f"{info['systemName'] if self.inputs.require_fqdn else info['systemName'].split('.')[0]}/{info['neighborInterfaceInfo']['interfaceId_v2']}"
+                    for info in lldp_neighbor_info
+                ]
                 self.result.is_failure(f"{neighbor} - Wrong LLDP neighbors: {', '.join(failure_msg)}")
