@@ -11,9 +11,9 @@ from typing import ClassVar, Literal
 
 from pydantic import Field
 
-from anta.custom_types import VlanId
+from anta.custom_types import Interface, InterfaceType, VlanId
 from anta.models import AntaCommand, AntaTemplate, AntaTest
-from anta.tools import get_value
+from anta.tools import get_value, is_interface_ignored
 
 
 class VerifySTPMode(AntaTest):
@@ -104,7 +104,7 @@ class VerifySTPCounters(AntaTest):
 
     Expected Results
     ----------------
-    * Success: The test will pass if there are NO STP BPDU packet errors under all interfaces participating in STP.
+    * Success: The test will pass if there are NO STP BPDU packet errors under all or on specified interfaces participating in STP.
     * Failure: The test will fail if there are STP BPDU packet errors on one or many interface(s).
 
     Examples
@@ -112,19 +112,43 @@ class VerifySTPCounters(AntaTest):
     ```yaml
     anta.tests.stp:
       - VerifySTPCounters:
+        interfaces:
+          - Ethernet10
+          - Ethernet12
+        ignored_interfaces:
+           - Vxlan1
+           - Loopback0
     ```
     """
 
     categories: ClassVar[list[str]] = ["stp"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show spanning-tree counters", revision=1)]
 
+    class Input(AntaTest.Input):
+        """Input model for the VerifySTPCounters test."""
+
+        interfaces: list[Interface] | None = None
+        """A list of interfaces to be tested. If not provided, all interfaces (excluding any in `ignored_interfaces`) are tested."""
+        ignored_interfaces: list[InterfaceType | Interface] | None = None
+        """A list of interfaces or interface types like Ethernet which will ignore all Ethernet interfaces."""
+
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifySTPCounters."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
+        interfaces = self.inputs.interfaces if self.inputs.interfaces else command_output["interfaces"].keys()
+
+        for interface in interfaces:
+            # Verification is skipped if the interface is in the ignored interfaces list.
+            if is_interface_ignored(interface, self.inputs.ignored_interfaces):
+                continue
+
+            # If specified interface is not configured, test fails
+            if (counters := get_value(command_output, f"interfaces..{interface}", separator="..")) is None:
+                self.result.is_failure(f"Interface: {interface} - Not found")
+                continue
 
-        for interface, counters in command_output["interfaces"].items():
             if counters["bpduTaggedError"] != 0:
                 self.result.is_failure(f"Interface {interface} - STP BPDU packet tagged errors count mismatch - Expected: 0 Actual: {counters['bpduTaggedError']}")
             if counters["bpduOtherError"] != 0:
