@@ -109,4 +109,4 @@ def main(args: list[str], output: Literal["svg", "txt"] = "svg") -> None:
 
 
 if __name__ == "__main__":
-    main(sys.argv[1:], "txt")
+    main(sys.argv[1:], "svg")
