@@ -26,9 +26,9 @@ from anta.tests.routing.isis import (
 from tests.units.anta_tests import test
 
 if TYPE_CHECKING:
-    from tests.units.anta_tests import AntaUnitTestDataDict
+    from tests.units.anta_tests import AntaUnitTestData
 
-DATA: AntaUnitTestDataDict = {
+DATA: AntaUnitTestData = {
     (VerifyISISNeighborState, "success-default-vrf"): {
         "eos_data": [
             {
