@@ -22,9 +22,9 @@ from anta.tests.aaa import (
 from tests.units.anta_tests import test
 
 if TYPE_CHECKING:
-    from tests.units.anta_tests import AntaUnitTestDataDict
+    from tests.units.anta_tests import AntaUnitTestData
 
-DATA: AntaUnitTestDataDict = {
+DATA: AntaUnitTestData = {
     (VerifyTacacsSourceIntf, "success"): {
         "eos_data": [
             {
