@@ -14,9 +14,9 @@ from anta.tests.avt import VerifyAVTPathHealth, VerifyAVTRole, VerifyAVTSpecific
 from tests.units.anta_tests import test
 
 if TYPE_CHECKING:
-    from tests.units.anta_tests import AntaUnitTestDataDict
+    from tests.units.anta_tests import AntaUnitTestData
 
-DATA: AntaUnitTestDataDict = {
+DATA: AntaUnitTestData = {
     (VerifyAVTPathHealth, "success"): {
         "eos_data": [
             {
