@@ -14,9 +14,9 @@ from anta.tests.evpn import VerifyEVPNType5Routes
 from tests.units.anta_tests import test
 
 if TYPE_CHECKING:
-    from tests.units.anta_tests import AntaUnitTestDataDict
+    from tests.units.anta_tests import AntaUnitTestData
 
-DATA: AntaUnitTestDataDict = {
+DATA: AntaUnitTestData = {
     (VerifyEVPNType5Routes, "success-all"): {
         "eos_data": [
             {
