@@ -6,7 +6,6 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import TYPE_CHECKING, Callable
 
 import pytest
 from rich.table import Table
@@ -14,16 +13,13 @@ from rich.table import Table
 from anta import RICH_COLOR_PALETTE
 from anta.reporter import ReportJinja, ReportTable
 from anta.result_manager.models import AntaTestStatus
-
-if TYPE_CHECKING:
-    from anta.result_manager import ResultManager
+from tests.units.conftest import DEVICE_NAME
+from tests.units.result_manager.conftest import FAKE_TEST, ResultManagerFactoryProtocol
 
 
 class TestReportTable:
     """Test ReportTable class."""
 
-    # not testing __init__ as nothing is going on there
-
     @pytest.mark.parametrize(
         ("usr_list", "delimiter", "expected_output"),
         [
@@ -51,22 +47,20 @@ class TestReportTable:
         assert report._split_list_to_txt_list(usr_list, delimiter) == expected_output
 
     @pytest.mark.parametrize(
-        "headers",
+        ("title", "columns"),
         [
-            pytest.param([], id="empty list"),
-            pytest.param(["elem1"], id="one elem list"),
-            pytest.param(["elem1", "elem2"], id="two elemst"),
+            pytest.param("", [], id="empty list"),
+            pytest.param("My title", ["elem1"], id="one elem list"),
+            pytest.param("Other title", ["elem1", "elem2"], id="two elemst"),
         ],
     )
-    def test__build_headers(self, headers: list[str]) -> None:
-        """Test _build_headers."""
-        report = ReportTable()
-        table = Table()
-        table_column_before = len(table.columns)
-        report._build_headers(headers, table)
-        assert len(table.columns) == table_column_before + len(headers)
+    def test__build_table(self, title: str, columns: list[str]) -> None:
+        """Test static method _build_table."""
+        table = ReportTable._build_table(title, columns)
+        assert len(table.columns) == len(columns)
         if len(table.columns) > 0:
-            assert table.columns[table_column_before].style == RICH_COLOR_PALETTE.HEADER
+            assert table.columns[0].style == RICH_COLOR_PALETTE.HEADER
+        assert table.title == title
 
     @pytest.mark.parametrize(
         ("status", "expected_status"),
@@ -79,10 +73,111 @@ class TestReportTable:
         ],
     )
     def test__color_result(self, status: AntaTestStatus, expected_status: str) -> None:
-        """Test _build_headers."""
+        """Test _color_result."""
         report = ReportTable()
         assert report._color_result(status) == expected_status
 
+    @pytest.mark.parametrize(
+        ("results_size"),
+        [
+            pytest.param(5, id="5 results"),
+            pytest.param(0, id="no results"),
+        ],
+    )
+    def test_generate(
+        self,
+        result_manager_factory: ResultManagerFactoryProtocol,
+        results_size: int,
+    ) -> None:
+        """Test report table."""
+        manager = result_manager_factory(size=results_size)
+
+        report = ReportTable()
+        res = report.generate(manager)
+
+        assert isinstance(res, Table)
+        assert res.row_count == results_size
+
+    @pytest.mark.parametrize(
+        ("results_size", "expected_length", "distinct", "tests_filter"),
+        [
+            pytest.param(5, 1, False, None, id="5 results, same test"),
+            pytest.param(5, 5, True, None, id="5 results, different tests"),
+            pytest.param(5, 0, True, {"BadTest"}, id="5 results, different tests, bad filter"),
+            pytest.param(5, 1, True, {FAKE_TEST.__name__ + "0"}, id="5 results, different tests, good filter"),
+            pytest.param(5, 2, True, {FAKE_TEST.__name__ + "0", FAKE_TEST.__name__ + "2"}, id="5 results, different tests, good filter 2"),
+            pytest.param(0, 0, False, None, id="no results"),
+        ],
+    )
+    def test_generate_summary_by_test(
+        self, result_manager_factory: ResultManagerFactoryProtocol, results_size: int, expected_length: int, distinct: bool, tests_filter: set[str] | None
+    ) -> None:
+        """Test generate_summary_by_test."""
+        manager = result_manager_factory(size=results_size, distinct_tests=distinct)
+
+        report = ReportTable()
+        res = report.generate_summary_by_test(manager, tests=tests_filter)
+
+        assert isinstance(res, Table)
+        assert res.row_count == expected_length
+
+    @pytest.mark.parametrize(
+        ("results_size", "expected_length", "distinct", "devices_filter"),
+        [
+            pytest.param(5, 1, False, None, id="5 results, same device"),
+            pytest.param(5, 5, True, None, id="5 results, different tests"),
+            pytest.param(5, 0, True, {"BadDevice"}, id="5 results, different tests, bad filter"),
+            pytest.param(5, 1, True, {DEVICE_NAME + "0"}, id="5 results, different tests, good filter"),
+            pytest.param(5, 2, True, {DEVICE_NAME + "0", DEVICE_NAME + "2"}, id="5 results, different tests, good filter 2"),
+            pytest.param(0, 0, False, None, id="no results"),
+        ],
+    )
+    def test_generate_summary_by_device(
+        self, result_manager_factory: ResultManagerFactoryProtocol, results_size: int, expected_length: int, distinct: bool, devices_filter: set[str] | None
+    ) -> None:
+        """Test generate_summary_by_device."""
+        manager = result_manager_factory(size=results_size, distinct_devices=distinct)
+
+        report = ReportTable()
+        res = report.generate_summary_by_device(manager, devices=devices_filter)
+
+        assert isinstance(res, Table)
+        assert res.row_count == expected_length
+
+    @pytest.mark.parametrize(
+        ("field", "function"),
+        [
+            pytest.param("all", "generate", id="generate()"),
+        ],
+    )
+    @pytest.mark.parametrize(
+        "title",
+        [
+            pytest.param(None, id="default"),
+            pytest.param("", id="empty string"),
+            pytest.param("My title", id="string"),
+        ],
+    )
+    def test_titles(
+        self,
+        result_manager_factory: ResultManagerFactoryProtocol,
+        field: str,
+        function: str,
+        title: str,
+    ) -> None:
+        """Test ReportTable title changes."""
+        manager = result_manager_factory(size=1)
+
+        report = ReportTable()
+        if title is not None:
+            setattr(report.title, field, title)
+        default = getattr(ReportTable.Title, field)
+        res = getattr(report, function)(manager)
+
+        assert isinstance(res, Table)
+        assert res.title == (title if title is not None else default)
+
+    ## deprecated methods tests
     @pytest.mark.parametrize(
         ("title", "number_of_tests", "expected_length"),
         [
@@ -94,7 +189,7 @@ class TestReportTable:
     )
     def test_report_all(
         self,
-        result_manager_factory: Callable[[int], ResultManager],
+        result_manager_factory: ResultManagerFactoryProtocol,
         title: str | None,
         number_of_tests: int,
         expected_length: int,
@@ -115,31 +210,24 @@ class TestReportTable:
         ("test", "title", "number_of_tests", "expected_length"),
         [
             pytest.param(None, None, 5, 5, id="all results"),
-            pytest.param("VerifyTest3", None, 5, 1, id="result for test VerifyTest3"),
+            pytest.param("FakeTestWithInput3", None, 5, 1, id="result for test FakeTestWithInput3"),
             pytest.param(None, "Custom title", 5, 5, id="Change table title"),
         ],
     )
     def test_report_summary_tests(
         self,
-        result_manager_factory: Callable[[int], ResultManager],
+        result_manager_factory: ResultManagerFactoryProtocol,
         test: str | None,
         title: str | None,
         number_of_tests: int,
         expected_length: int,
     ) -> None:
         """Test report_summary_tests."""
-        # TODO: refactor this later... this is injecting double test results by modyfing the device name
-        # should be a fixture
-        manager = result_manager_factory(number_of_tests)
-        new_results = [result.model_copy() for result in manager.results]
-        for result in new_results:
-            result.name = "test_device"
-            result.result = AntaTestStatus.FAILURE
+        manager = result_manager_factory(number_of_tests, distinct_tests=True)
 
         report = ReportTable()
-        kwargs = {"tests": [test] if test is not None else None, "title": title}
-        kwargs = {k: v for k, v in kwargs.items() if v is not None}
-        res = report.report_summary_tests(manager, **kwargs)  # type: ignore[arg-type]
+        tests = [test] if test is not None else None
+        res = report.report_summary_tests(manager, tests=tests, title=title) if title else report.report_summary_tests(manager, tests=tests)
 
         assert isinstance(res, Table)
         assert res.title == (title or "Summary per test")
@@ -149,32 +237,25 @@ class TestReportTable:
         ("dev", "title", "number_of_tests", "expected_length"),
         [
             pytest.param(None, None, 5, 1, id="all results"),
-            pytest.param("device1", None, 5, 1, id="result for host host1"),
+            pytest.param("pytest3", None, 5, 1, id="result for host pytest3"),
             pytest.param(None, "Custom title", 5, 1, id="Change table title"),
         ],
     )
     def test_report_summary_devices(
         self,
-        result_manager_factory: Callable[[int], ResultManager],
+        result_manager_factory: ResultManagerFactoryProtocol,
         dev: str | None,
         title: str | None,
         number_of_tests: int,
         expected_length: int,
     ) -> None:
         """Test report_summary_devices."""
-        # TODO: refactor this later... this is injecting double test results by modyfing the device name
-        # should be a fixture
-        manager = result_manager_factory(number_of_tests)
-        new_results = [result.model_copy() for result in manager.results]
-        for result in new_results:
-            result.name = dev or "test_device"
-            result.result = AntaTestStatus.FAILURE
-        manager.results = new_results
+        # Changing device name if a device was given - this test will go away so can be refactored later
+        manager = result_manager_factory(number_of_tests, distinct_devices=True) if dev else result_manager_factory(number_of_tests, distinct_devices=False)
 
         report = ReportTable()
-        kwargs = {"devices": [dev] if dev is not None else None, "title": title}
-        kwargs = {k: v for k, v in kwargs.items() if v is not None}
-        res = report.report_summary_devices(manager, **kwargs)  # type: ignore[arg-type]
+        devices = [dev] if dev is not None else None
+        res = report.report_summary_devices(manager, devices=devices, title=title) if title else report.report_summary_devices(manager, devices=devices)
 
         assert isinstance(res, Table)
         assert res.title == (title or "Summary per device")
